@@ -1,58 +1,7 @@
 reposToolsCurrentInstalls <- list()
 
 
-checkImports <- function(lib) {
-    ## FIXME: To be removed for 1.6
-    origOpt <- getOption("show.error.messages")
-    on.exit(options(show.error.messages=origOpt), add=TRUE)
 
-    for (curLib in lib) {
-        if (load.locLib(curLib) == FALSE)
-            next
-
-        options(show.error.messages=FALSE)
-
-        for (i in seq(along=locLibList)) {
-            z <- try(Imports(locLibList[[i]]))
-            if (is(z, "try-error"))
-                locLibList[[i]]@Imports <- "NA"
-        }
-
-        options(show.error.messages=origOpt)
-
-        save.locLib(locLibList, curLib)
-    }
-
-    NULL
-}
-
-
-checkLocLibBundles <- function(lib) {
-    ## FIXME: temporary function to sync up all the older loclibs
-    ## to the new object structure w/ bundles.  This can be taken
-    ## out for teh BioC 1.5 release
-    origOpt <- getOption("show.error.messages")
-    on.exit(options(show.error.messages=origOpt), add=TRUE)
-
-    for (curLib in lib) {
-        if (load.locLib(curLib) == FALSE)
-            next
-
-        options(show.error.messages=FALSE)
-
-        for (i in seq(along=locLibList)) {
-            z <- try(Bundle(locLibList[[i]]))
-            if (is(z, "try-error"))
-                locLibList[[i]]@Bundle <- "NA"
-        }
-
-        options(show.error.messages=origOpt)
-
-        save.locLib(locLibList, curLib)
-    }
-
-    NULL
-}
 
 syncLocalLibList <- function(lib=reposToolsLibPaths(), quiet=TRUE) {
     ## Need to see if there currently exists a 'liblisting.Rda' in lib
@@ -60,11 +9,6 @@ syncLocalLibList <- function(lib=reposToolsLibPaths(), quiet=TRUE) {
     if (!quiet)
         cat("\nSynching your local package management information ...\n")
 
-    for (curLib in lib) {
-        checkLocLibBundles(lib)
-        checkImports(lib)
-    }
-
     ## Create a locale for any temporary lib dirs, if needed
     tmpLibDir <- file.path(tempdir(),"tempLibs")
     if (! file.exists(tmpLibDir))
@@ -106,6 +50,9 @@ syncLocalLibList <- function(lib=reposToolsLibPaths(), quiet=TRUE) {
                 next
             }
 
+            if (length(pkgs) == 0)
+                next
+
             ## Figure out which packages are already in the database,
             ## and which ones are new
             curLocPkgs <- unlist(lapply(locLibList, Package))
@@ -587,10 +534,11 @@ solveForwardDepends <- function(pkgInfo, repEntry, lib, depLevel,
                 if (!is.null(depVers))
                     errMsg <- paste(errMsg,"version",depOper,depVers)
                 if (getAllDeps == FALSE) {
-                    outErrMsg <- paste(errMsg,", would you like to try ",
-                                       "to install this package?",
-                                       sep="")
-                    ans <- userQuery(outErrMsg,c("yes","no"))
+                    ##outErrMsg <- paste(errMsg,", would you like to try ",
+                    ##                   "to install this package?",
+                    ##                   sep="")
+                    ##ans <- userQuery(outErrMsg,c("yes","no"))
+                    ans <- "no"
                 }
                 else
                     ans <- "yes"
@@ -719,8 +667,11 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
     if (missing(lib))
         lib <- reposToolsLibPaths()[1]
     else
-        if (! lib %in% .libPaths())
-            .libPaths(lib)
+        if (! lib %in% .libPaths()) {
+            paths <- .libPaths()
+            paths <- c(lib, paths)
+            .libPaths(paths)
+        }
 
     ## We need to make sure that lib is in the R_LIBS
     ## environment variable, due to source installs.  Win32 installs
@@ -800,9 +751,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("You did not specify a download type.",
-                       " Using a default value of:",type,
-                       "\nThis will be fine for almost all users\n"))
+            note(paste("Using download type:", type))
     }
 
     ## Make sure that the requested lib directory is synch'ed
@@ -841,17 +790,21 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
 
     ## FIXME:
     pkgsDLd <- foundPkgs(pStatList)
-    if (length(pkgsDLd) != length(pkgs)) {
+    if (length(pkgsDLd) < length(pkgs)) {
         nfPkgs <- pkgs[! pkgs %in% pkgsDLd]
         availPkgs <- repPkgs(repList)
 
         for (i in seq(along = nfPkgs)) {
-            sim <- agrep(nfPkgs[i], availPkgs)
-            if (length(sim) > 0) {
-                newList <- vector(mode="list", length=1)
-                names(newList) <- nfPkgs[i]
-                newList[[1]] <- availPkgs[sim]
-                matchesList(pStatList) <- newList
+            if (length(nfPkgs[i]) > 0) {
+                sim <- agrep(nfPkgs[i], availPkgs,
+                             max.distance=list(all=0.05,
+                             insertions=3, deletions=3, substitutions=3))
+                if (length(sim) > 0) {
+                    newList <- vector(mode="list", length=1)
+                    names(newList) <- nfPkgs[i]
+                    newList[[1]] <- availPkgs[sim]
+                    matchesList(pStatList) <- newList
+                }
             }
         }
     }
@@ -887,9 +840,7 @@ download.packages2 <- function(pkgs, repEntry, destDir, versions,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("You did not specify a download type.",
-                       " Using a default value of:",type,
-                       "\nThis will be fine for almost all users\n"))
+            note(paste("Using download type:", type))
     }
 
     if (missing(pkgs)) {
@@ -992,9 +943,7 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("You did not specify a download type.",
-                       " Using a default value of:",type,
-                       "\nThis will be fine for almost all users\n"))
+            note(paste("Using download type:", type))
     }
 
     out <- vector(mode="list", length=length(libs))
@@ -1429,3 +1378,54 @@ buildRepList <- function(repEntry=NULL, recurse=TRUE,
 }
 
 
+browseRepos <- function(repEntry) {
+    brURL <- paste(repURL(repEntry), "/html/index.html", sep="")
+
+    curErr <- getOption("show.error.messages")
+    options(show.error.messages = FALSE)
+    on.exit(options(show.error.messages = curErr))
+    ## Check to see if it is there
+    testConn <- url(brURL)
+    z <- try(readLines(testConn, n=1))
+    close(testConn)
+    if (is(z, "try-error") == TRUE) {
+        warning("No browsable HTML for this repository")
+        return(FALSE)
+    }
+    else
+        browseURL(brURL)
+}
+
+checkRepos <- function(repEntry) {
+    rdd <- repdataframe(repEntry)
+    osS <- rdd$OSspecific
+
+    repU <- repURL(repEntry)
+
+    out <- character()
+
+    oOpt <- getOption("show.error.messages")
+    on.exit(options(show.error.messages=oOpt), add=TRUE)
+
+    for (i in seq(along=osS)) {
+        for (j in seq(along=osS[[i]])) {
+            link <- url(paste(repU, osS[[i]][[j]]$File, sep="/"))
+            options(show.error.messages=FALSE)
+            lines <- try(readLines(link, n=1))
+            options(show.error.messages=oOpt)
+            close(link)
+            if ((is(lines, "try-error"))||(lines == "<html>")) {
+                out <-c(out, basename(osS[[i]][[j]]$File))
+            }
+        }
+    }
+
+    if (length(out) > 0) {
+        cat("The following packages are not accessible at ",
+            repName(z), ":\n\t", sep="")
+        cat(paste(out, collapse="\n\t"))
+        cat("\n")
+    }
+    else
+        NULL
+}
