@@ -75,7 +75,9 @@ loadRepDD <- function(repURL, repDD="repdatadesc.rda", method) {
         method <- "auto"
 
     options(show.error.messages=FALSE)
-    retVal <- try(loadURL(ddURL, quiet=TRUE, mode="wb", method=method))
+    conn <- url(ddURL)
+    retVal <- try(load(conn))
+    close(conn)
     options(show.error.messages=TRUE)
 
     if (is(retVal, "try-error")) {
@@ -915,6 +917,7 @@ installPkgListing <- function(pkgList, lib, type, method="auto",
                                     stringRep(pkgVersion(curPkgInfo)),
                                     lib=lib, type=type, method=method,
                                     versForce=versForce)
+                gotPkgs[[length(gotPkgs)+1]] <- curPkgInfo
             }
             else
                 ret <- FALSE
